@@ -24,7 +24,11 @@ cat("Iteration process:", "\n")
 
 if(x$conv==1) cat("Convergence criteria satisfied")
 if(x$conv==2) cat("Maximum number of iteration reached without convergence")
-if(x$conv==4|x$conv==5) stop("Program stopped, please check the data and model specification")
+if(x$conv==4|x$conv==5)  {
+cat("The program stopped abnormally. No results can be displayed.\n")
+}else{
+
+
 
 cat(" \n")
 cat("     Number of iterations: ", x$niter, "\n")
@@ -40,4 +44,4 @@ cat(" \n")
 cat(" \n")
 
 }
-
+}
