@@ -55,7 +55,7 @@ if ((all.equal(x$conv,1)==T)==T){
 id <- 1:NPM
 indice <- rep(id*(id+1)/2)
 se <-sqrt(x$V[indice])
-se[(NPROB+NEF+1):(NPROB+NEF+NVC)]<-1
+if (NVC>0) se[(NPROB+NEF+1):(NPROB+NEF+NVC)]<-1
 wald <- x$best/se
 pwald <- 1-pchisq(wald**2,1)
 coef <- x$best
@@ -70,6 +70,7 @@ coef <- x$best
 
 if(NPROB>0){
 cat("Fixed effects in the class-membership model:\n" )
+cat("(the class of reference is the last class) \n")
 
 tmp <- cbind(coef[1:NPROB],se[1:NPROB],wald[1:NPROB],pwald[1:NPROB])
 dimnames(tmp) <- list(names(coef)[1:NPROB], c("coef", "Se", "Wald", "p-value"))
@@ -93,7 +94,11 @@ if(NVC>0){
 cat("\n")
 cat("Variance-covariance matrix of the random-effects:\n" )
 if(x$idiag==1){
+if (NVC>1) {
 Mat.cov <- diag(coef[(NPROB+NEF+1):(NPROB+NEF+NVC)])
+}else{
+Mat.cov <- matrix(coef[(NPROB+NEF+1)],ncol=1)
+}
 colnames(Mat.cov) <-x$name.mat.cov 
 rownames(Mat.cov) <-x$name.mat.cov 
 Mat.cov[lower.tri(Mat.cov)] <- 0
